animated_cycler library

AnimatedCycler - A versatile Flutter widget for cycling through content

This library provides the AnimatedCycler widget that automatically cycles through a list of items with smooth bidirectional animations.

Classes

AnimatedCycler<T>
A versatile animated widget that automatically cycles through a list of items with smooth bidirectional animations.
AnimatedCyclerState<T>
The state class for AnimatedCycler that provides manual control methods.