items property
The list of items to cycle through.
Must not be null. If empty, the widget will display an empty container.
Implementation
final List<T> items;
The list of items to cycle through.
Must not be null. If empty, the widget will display an empty container.
final List<T> items;